About
=====

Generates stubs for python modules

There are several tweaks to target specifically modules compiled using `pybind11 <https://github.com/pybind/pybind11>`_

Currently supprorts only python3

Issues/PR are welcome

Usage 
=====


.. code:: bash

    pybind11_stubgen.py [-h] [-o OUTPUT_DIR] MODULE_NAME [MODULE_NAME ...]


